;; Generated package description from org-gnosis.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "org-gnosis" "0.0.9" "Roam-like Knowledge Management System" '((emacs "27.2") (emacsql "4.0.0") (compat "29.1.4.2")) :commit "2f1ed5320b8e9b31c67c0720be2693fe416f16a1" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("extensions") :url "https://thanosapollo.org/projects/org-gnosis/")
